#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['forecastvh']

package_data = \
{'': ['*']}

setup(name='forecastvh',
      version='0.0.1b3',
      description="Let's see the weather outside!",
      author='Ilia Fedorovich',
      author_email='workplaceilfed@gmail.com',
      url='https://github.com/MorningStar-png/weathervh-py',
      packages=packages,
      package_data=package_data,
      python_requires='>=3.8',
     )
